import { ITopic } from 'aws-cdk-lib/aws-sns';
import { IConstruct } from 'constructs';
import { AlertManagerDestinationCategory, IAlertManagerDestination } from './destination-base';
/**
 * Optional configuration for an alert manager SNS destination.
 */
export interface AlertManagerSnsDestinationOptions {
    /**
     * The SNS API URL i.e. https://sns.us-east-2.amazonaws.com.
     *
     * If not specified, the SNS API URL from the SNS SDK will be used.
     */
    readonly apiUrl?: string;
    /**
     * SNS message attributes.
     */
    readonly attributes?: {
        [key: string]: string;
    };
    /**
     * The message content of the SNS notification.
     */
    readonly message?: string;
    /**
     * Controls whether to notify about resolved alerts.
     */
    readonly sendResolved?: boolean;
    /**
     * Subject line when the message is delivered to email endpoints.
     */
    readonly subject?: string;
}
/**
 * Configuration for an alert manager SNS destination.
 */
export interface AlertManagerSnsDestinationProps extends AlertManagerSnsDestinationOptions {
    /**
     * SNS topic where alerts will be sent.
     *
     * If you are using a FIFO SNS topic you should set a message group interval
     * longer than 5 minutes to prevent messages with the same group key being
     * deduplicated by the SNS default deduplication window.
     */
    readonly topic: ITopic;
}
/**
 * An alert manager destination that provides details for sending alert
 * notifications to an Amazon SNS topic.
 *
 * @see [Alert manager SNS configuration](https://prometheus.io/docs/alerting/latest/configuration/#sns_config)
 */
export declare class AlertManagerSnsDestination implements IAlertManagerDestination {
    /**
     * Internal collection of attributes to be applied to SNS messages.
     */
    private readonly _attributes;
    /**
     * The SNS API URL i.e. https://sns.us-east-2.amazonaws.com.
     *
     * If not specified, the SNS API URL from the SNS SDK will be used.
     *
     * @group Inputs
     */
    readonly apiUrl?: string;
    /**
     * The message content of the SNS notification.
     *
     * @group Inputs
     */
    readonly message?: string;
    /**
     * Controls whether to notify about resolved alerts.
     *
     * @group Inputs
     */
    readonly sendResolved?: boolean;
    /**
     * Subject line when the message is delivered to email endpoints.
     *
     * @groups Inputs
     */
    readonly subject?: string;
    /**
     * SNS topic where alerts will be sent.
     *
     * If you are using a FIFO SNS topic you should set a message group interval
     * longer than 5 minutes to prevent messages with the same group key being
     * deduplicated by the SNS default deduplication window.
     *
     * @group Inputs
     */
    readonly topic: ITopic;
    /**
     * Attributes to be applied to SNS messages.
     *
     * @group Inputs
     */
    get attributes(): {
        [key: string]: string;
    };
    /**
     * The destination type being configured.
     *
     * Represents a config block in an alert manager receiver configuration.
     */
    readonly category: AlertManagerDestinationCategory;
    /**
     * Creates a new instance of the AlertManagerSnsDestination class.
     *
     * @param options Arguments related to the configuration of the destination.
     */
    constructor(options: AlertManagerSnsDestinationProps);
    /**
     * Registers a new attribute to be added to sent SNS messages.
     *
     * @param key The name of the attribute.
     * @param value The value to use for the named attribute.
     * @returns The sns destination object the attribute was added to.
     */
    addAttribute(key: string, value: string): AlertManagerSnsDestination;
    /**
     * Associates the destination with a construct that is handling the
     * configuration of alert manager.
     *
     * @param scope The construct handling alert manager configuration.
     * @returns An object representing the configured destination.
     */
    bind(scope: IConstruct): {
        [key: string]: any;
    };
}
