import { IConstruct } from 'constructs';
import { IPrometheusRule } from './prometheus-rule-base';
/**
 * Options needed to configure a Prometheus recording rule inside an APS rules
 * configuration.
 */
export interface RecordingRuleProps {
    /**
     * The PromQL expression to evaluate. Every evaluation cycle this is
     * evaluated at the current time, and the result recorded as a new set of
     * time series with the metric name as given by `record`.
     *
     * @see [Querying prometheus](https://prometheus.io/docs/prometheus/latest/querying/basics/)
     */
    readonly expression: string;
    /**
     * Labels to add or overwrite before storing the result.
     */
    readonly labels?: {
        [labelName: string]: string;
    };
    /**
     * The name of the time series to output to. Must be a valid metric name.
     */
    readonly record: string;
}
/**
 * Recording rules allow you to precompute frequently needed or computationally
 * expensive expressions and save their result as a new set of time series.
 * Querying the precomputed result will then often be much faster than
 * executing the original expression every time it is needed. This is
 * especially useful for dashboards, which need to query the same expression
 * repeatedly every time they refresh.
 *
 * @see [Defining recording rules](https://prometheus.io/docs/prometheus/latest/configuration/recording_rules/)
 */
export declare class RecordingRule implements IPrometheusRule {
    /**
     * Internal collection of labels to add or overwrite before storing the
     * result.
     */
    private readonly _labels;
    /**
     * The PromQL expression to evaluate. Every evaluation cycle this is
     * evaluated at the current time, and the result recorded as a new set of
     * time series with the metric name as given by `record`.
     *
     * @see [Querying prometheus](https://prometheus.io/docs/prometheus/latest/querying/basics/)
     *
     * @group Inputs
     */
    readonly expression: string;
    /**
     * The name of the time series to output to. Must be a valid metric name.
     *
     * @group Inputs
     */
    readonly record: string;
    /**
     * Labels to add or overwrite before storing the result.
     */
    get labels(): {
        [labelName: string]: string;
    };
    /**
     * Creates a new instance of the RecordingRule class.
     *
     * @param props Arguments defining the configuration of the reporting rule.
     */
    constructor(props: RecordingRuleProps);
    /**
     * Sets a new label and value that will be added or overridden before storing
     * the result.
     *
     * @param label The name of the label to add.
     * @param value The values of the label to add.
     * @returns The recording rule that the label was added to.
     */
    addLabel(label: string, value: string): RecordingRule;
    /**
     * Associates the recording rule with a construct that is configuring an APS
     * rule groups namespace.
     *
     * @param _scope The construct handling the configuration of the APS rule
     * groups namespace that will be consuming this rule.
     * @returns The rendered configuration for the rule as expected by and APS
     * rules config file.
     */
    bind(_scope: IConstruct): {
        [key: string]: any;
    };
}
