import { Resource, ResourceProps } from 'aws-cdk-lib';
import { CfnRuleGroupsNamespace } from 'aws-cdk-lib/aws-aps';
import { IConstruct } from 'constructs';
import { IWorkspace } from '.';
import { RuleGroup, RuleGroupProps } from './lib/rules/rule-group';
import { IRuleGroupConfiguration } from './lib/rules/rule-group-configuration';
/**
 * Represents an APS rule groups namespace in AWS.
 */
export interface IRuleGroupsNamespace {
    /**
     * The Amazon Resource Name (ARN) of the APS rule groups namespace.
     */
    readonly rulesGroupsNamespaceArn: string;
}
/**
 * A base class providing common functionality between created and imported APS
 * rule groups namespaces.
 */
declare abstract class RuleGroupsNamespaceBase extends Resource implements IRuleGroupsNamespace {
    /**
     * The Amazon Resource Name (ARN) of the APS rule groups namespace.
     */
    abstract readonly rulesGroupsNamespaceArn: string;
}
/**
 * Configuration for the RuleGroupsNamespace resource.
 */
export interface RuleGroupsNamespaceProps extends ResourceProps {
    /**
     * The rules definition file for this namespace.
     *
     * @see [RuleGroupsNamespace Data](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aps-rulegroupsnamespace.html#cfn-aps-rulegroupsnamespace-data)
     */
    readonly configuration?: IRuleGroupConfiguration;
    /**
     * The name of the rule groups namespace.
     *
     * @see [RuleGroupsNamespace Name](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aps-rulegroupsnamespace.html#cfn-aps-rulegroupsnamespace-name)
     */
    readonly name?: string;
    /**
     * The APS workspace that contains this rule groups namespace.
     *
     * @see [RuleGroupsNamespace Workspace](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aps-rulegroupsnamespace.html#cfn-aps-rulegroupsnamespace-workspace)
     */
    readonly workspace: IWorkspace;
}
/**
 * Amazon Managed Service for Prometheus allows for the configuration of rules
 * that configure alerting and precomputation of frequently needed expressions.
 *
 * These rules are added to a workspace using configurations that define one or
 * more resource groups. Eache group can contain one or more rules and
 * configures the frequency that its rules should be evaluated.
 *
 * You can have multiple configurations per workspace. Each configuration is
 * contained in a separate _namespace_. Having multiple configuration lets you
 * import existing Prometheus rules files to a workspace without having to
 * change or combine them. Different rule group namespaces can also have
 * different tags.
 *
 * @see [AWS::APS::RuleGroupsNamespace](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aps-rulegroupsnamespace.html)
 * @see [Recording rules and alerting rules](https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-Ruler.html)
 */
export declare class RuleGroupsNamespace extends RuleGroupsNamespaceBase {
    /**
     * Imports an existing APS rule groups namespace by specifying its Amazon
     * Resource Name (ARN).
     *
     * @param scope A CDK Construct that will serve as this resources's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param arn The ARN of the existing APS rule groups namespace. to be
     * imported.
     * @returns An object representing the imported APS rule groups namespace.
     */
    static fromRuleGroupsNamespaceArn(scope: IConstruct, id: string, arn: string): IRuleGroupsNamespace;
    /**
     * The rules definition file for this namespace.
     *
     * @see [RuleGroupsNamespace Data](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aps-rulegroupsnamespace.html#cfn-aps-rulegroupsnamespace-data)
     *
     * @group Inputs
     */
    readonly configuration: IRuleGroupConfiguration;
    /**
     * The name of the rule groups namespace.
     *
     * @see [RuleGroupsNamespace Name](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aps-rulegroupsnamespace.html#cfn-aps-rulegroupsnamespace-name)
     *
     * @group Inputs
     */
    readonly name: string;
    /**
     * The APS workspace that contains this rule groups namespace.
     *
     * @see [RuleGroupsNamespace Workspace](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aps-rulegroupsnamespace.html#cfn-aps-rulegroupsnamespace-workspace)
     *
     * @group Inputs
     */
    readonly workspace: IWorkspace;
    /**
     * The underlying RuleGroupsNamespace CloudFormation resource.
     *
     * @see [AWS::APS::RuleGroupsNamespace](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aps-rulegroupsnamespace.html)
     *
     * @group Resources
     */
    readonly resource: CfnRuleGroupsNamespace;
    /**
     * The Amazon Resource Name (ARN) of the APS rule groups namespace.
     */
    readonly rulesGroupsNamespaceArn: string;
    /**
     * Creates a new instance of the RuleGroupsNamespace class.
     *
     * @param scope A CDK Construct that will serve as this resource's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param props Arguments related to the configuration of the resource.
     */
    constructor(scope: IConstruct, id: string, props: RuleGroupsNamespaceProps);
    /**
     * Adds a new rule group to the configuration.
     *
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param options Configuration options for the new rule group being added.
     * @returns The rule group that was added.
     */
    addRuleGroup(id: string, options?: RuleGroupProps): RuleGroup;
}
export {};
